package com.caimei365.user.mapper;

import com.caimei365.user.model.dto.ClubOnlineDto;
import com.caimei365.user.model.dto.ShopApplyDto;
import com.caimei365.user.model.po.ClubPo;
import com.caimei365.user.model.po.OperationPo;
import com.caimei365.user.model.po.ShopPo;
import com.caimei365.user.model.po.UserPo;
import com.caimei365.user.model.vo.ClubTemporaryVo;
import com.caimei365.user.model.po.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/8
 */
@Mapper
public interface RegisterMapper {
    /**
     * 保存(机构)用户（user）
     *
     * @param user
     * @return
     */
    int insertClubUser(UserPo user);

    /**
     * 保存普通机构（club）
     *
     * @param club
     * @return
     */
    int insertClub(ClubPo club);

    /**
     * 保存会员机构（club）
     *
     * @param club
     * @return
     */
    int insertUpgradeClub(ClubPo club);

    /**
     * 保存运营人员（operation）
     *
     * @param operation
     * @return
     */
    int insertOperation(OperationPo operation);

    /**
     * 保存(供应商)用户（user）
     *
     * @param user
     * @return
     */
    void insertShopUser(UserPo user);

    /**
     * 保存供应商（shop）
     *
     * @param shop
     * @return
     */
    int insertShop(ShopPo shop);

    /**
     * 根据用户ID更新机构ID
     *
     * @param userId
     * @param clubId
     */
    void updateUserClubId(@Param("userId") Integer userId, @Param("clubId") Integer clubId);

    /**
     * 根据用户ID更新供应商ID
     *
     * @param userId
     * @param shopId
     */
    void updateUserShopId(@Param("userId") Integer userId, @Param("shopId") Integer shopId);

    /**
     * 升级机构 更新user
     *
     * @param user
     */
    void updateClubUserByUpgrade(UserPo user);

    /**
     * 修改供应商申请信息 更新user
     *
     * @param user
     */
    void updateShopUserByApply(UserPo user);

    /**
     * 升级机构 更新club
     *
     * @param club
     */
    void updateClubByUpgrade(ClubPo club);

    /**
     * 修改供应商申请信息 更新shop
     *
     * @param shop
     */
    void updateShopInfoByApply(ShopApplyDto shop);

    /**
     * 引导升级后改变guideFlag状态
     *
     * @param userId
     */
    void updateGuideFlagByUserId(Integer userId);

    /**
     * 保存机构临时数据
     *
     * @param onlineDto
     */
    void insertClubTemporary(ClubOnlineDto onlineDto);

    /**
     * 中间表数据
     *
     * @param id
     * @return
     */
    ClubTemporaryVo getTemporary(Integer id);

    /**
     * 保存采美豆记录
     *
     * @param beansHistory
     */
    void insertBeansHistory(UserBeansHistoryPo beansHistory);
}
